@@ -10,8 +10,10 @@ txaio.use_twisted()
 
 from ._version import __version__  # noqa
 from ._exception import InvalidConfigException  # noqa
-from .common import address, uint256, unpack_uint256, pack_uint256,\
-    uint128, unpack_uint128, pack_uint128  # noqa
+from .common import address  # noqa
+from .common import uint256, unpack_uint256, pack_uint256  # noqa
+from .common import uint128, unpack_uint128, pack_uint128  # noqa
+from .common import uint64, unpack_uint64, pack_uint64  # noqa
 from . import meta, mrealm, xbr, xbrmm, xbrnetwork  # noqa
 from . import schema, globalschema, mrealmschema  # noqa
 
@@ -29,6 +31,9 @@ __all__ = (
     'uint128',
     'pack_uint128',
     'unpack_uint128',
+    'uint64',
+    'pack_uint64',
+    'unpack_uint64',
     'schema',
     'globalschema',
     'mrealmschema',
